@@ -1,15 +1,15 @@
 context("feather serializer")
 
 test_that("feather serializes properly", {
-  skip_if_not_installed("feather")
+  skip_if_not_installed("arrow")
 
   d <- data.frame(a=1, b=2, c="hi")
   val <- serializer_feather()(d, data.frame(), PlumberResponse$new(), stop)
   expect_equal(val$status, 200L)
-  expect_equal(val$headers$`Content-Type`, "application/feather")
+  expect_equal(val$headers$`Content-Type`, "application/vnd.apache.arrow.file")
 
   # can test  by doing a full round trip if we believe the parser works via `test-parse-body.R`
-  parsed <- parse_body(val$body, "application/feather", make_parser("feather"))
+  parsed <- parse_body(val$body, "application/vnd.apache.arrow.file", make_parser("feather"))
   # convert from feather tibble to data.frame
   parsed <- as.data.frame(parsed, stringsAsFactors = FALSE)
   attr(parsed, "spec") <- NULL
@@ -18,7 +18,7 @@ test_that("feather serializes properly", {
 })
 
 test_that("Errors call error handler", {
-  skip_if_not_installed("feather")
+  skip_if_not_installed("arrow")
 
   errors <- 0
   errHandler <- function(req, res, err){
@@ -31,7 +31,7 @@ test_that("Errors call error handler", {
 })
 
 test_that("Errors are rendered correctly with debug TRUE", {
-  skip_if_not_installed("feather")
+  skip_if_not_installed("arrow")
 
   pr <- pr() %>% pr_get("/", function() stop("myerror"), serializer = serializer_feather()) %>% pr_set_debug(TRUE)
   capture.output(res <- pr$serve(make_req(pr = pr), PlumberResponse$new("csv")))
